==========================
SciPy 0.12.1 Release Notes
==========================

SciPy 0.12.1 is a bug-fix release with no new features compared to 0.12.0.
The single issue fixed by this release is a security issue in ``scipy.weave``,
which was previously using temporary directories in an insecure manner under 
certain circumstances.
